# Changelog

## [0.2.32](https://github.com/uptick/datawarehouse/compare/0.2.31...v0.2.32) (2025-02-26)


### Bug Fixes

* **accounts:** fix datawarehouse models ([dd9a2a1](https://github.com/uptick/datawarehouse/commit/dd9a2a1310638e81f07a50dfcbbe2286a978d5d5))
